dio_retry_it library

Retry library for Dio package made with love

Classes

RetryInterceptor
An interceptor that automatically retries failed requests using exponential backoff with full jitter.

Extensions

OptionsX on Options
Retry-related properties on Options.
RequestOptionsX on RequestOptions
Retry-related properties on RequestOptions.

Constants

clientErrorStatuses → const Set<int>
All 4xx status codes
cloudflareStatuses → const Set<int>
All Cloudflare-specific status codes
defaultRetryableStatuses → const Set<int>
informationalStatuses → const Set<int>
All 1xx status codes
redirectionStatuses → const Set<int>
All 3xx status codes
serverErrorStatuses → const Set<int>
All 5xx status codes
status100Continue → const int
status101SwitchingProtocols → const int
status102Processing → const int
status200OK → const int
status201Created → const int
status202Accepted → const int
status203NonAuthoritative → const int
status204NoContent → const int
status205ResetContent → const int
status206PartialContent → const int
status207Multistatus → const int
status208AlreadyReported → const int
status226IMUsed → const int
status300MultipleChoices → const int
status301MovedPermanently → const int
status302Found → const int
status303SeeOther → const int
status304NotModified → const int
status305UseProxy → const int
status306SwitchProxy → const int
status307TemporaryRedirect → const int
status308PermanentRedirect → const int
status400BadRequest → const int
status401Unauthorized → const int
status402PaymentRequired → const int
status403Forbidden → const int
status404NotFound → const int
status405MethodNotAllowed → const int
status406NotAcceptable → const int
status407ProxyAuthenticationRequired → const int
status408RequestTimeout → const int
status409Conflict → const int
status410Gone → const int
status411LengthRequired → const int
status412PreconditionFailed → const int
status413PayloadTooLarge → const int
status413RequestEntityTooLarge → const int
status414RequestUriTooLong → const int
status414UriTooLong → const int
status415UnsupportedMediaType → const int
status416RangeNotSatisfiable → const int
status416RequestedRangeNotSatisfiable → const int
status417ExpectationFailed → const int
status418ImATeapot → const int
status419AuthenticationTimeout → const int
status421MisdirectedRequest → const int
status422UnprocessableEntity → const int
status423Locked → const int
status424FailedDependency → const int
status426UpgradeRequired → const int
status428PreconditionRequired → const int
status429TooManyRequests → const int
status431RequestHeaderFieldsTooLarge → const int
status440LoginTimeout → const int
status451UnavailableForLegalReasons → const int
status460ClientClosedRequest → const int
status499ClientClosedRequest → const int
status500InternalServerError → const int
status501NotImplemented → const int
status502BadGateway → const int
status503ServiceUnavailable → const int
status504GatewayTimeout → const int
status505HttpVersionNotSupported → const int
status506VariantAlsoNegotiates → const int
status507InsufficientStorage → const int
status508LoopDetected → const int
status510NotExtended → const int
status511NetworkAuthenticationRequired → const int
status520WebServerReturnedUnknownError → const int
status521WebServerIsDown → const int
status522ConnectionTimedOut → const int
status523OriginIsUnreachable → const int
status524TimeoutOccurred → const int
status525SSLHandshakeFailed → const int
status526InvalidSSLCertificate → const int
status527RailgunError → const int
status598NetworkReadTimeoutError → const int
status599NetworkConnectTimeoutError → const int
successStatuses → const Set<int>
All 2xx status codes

Typedefs

RetryEvaluator = FutureOr<bool> Function(DioException error, int attempt)
A function that evaluates whether a retry should be attempted.